@@ -1,4 +1,3 @@
-import os
 import unittest
 import doctest 
 from pprint import pprint
@@ -11,11 +10,9 @@ optionflags = doctest.NORMALIZE_WHITESPACE | \
 
 TESTFILES = [
     'parser.txt',
-    '../../../README.rst',
+    'sphinx.txt',
 ]
 
-DEMO_FORM_PATH = os.path.join(os.path.split(__file__)[0], 'demo_form.yaml')
-
 
 def test_vocab():
     """Used by tests to determine package path
@@ -39,8 +36,7 @@ def test_suite():
             optionflags=optionflags,
             globs={'interact': interact,
                    'pprint': pprint,
-                   'pxml': pxml,
-                   'demo_form_path': DEMO_FORM_PATH},
+                   'pxml': pxml},
         ) for file in TESTFILES
     ])
 
